Skip to contents

Delay discounting survey data from 434 adult subjects who reported having obesity and type 2 diabetes.

Usage

remedi

Format

remedi

A data frame with 3,038 rows and 5 columns:

study

Study name (always REMEDI)

subj

Subject ID Number

group

Condition group

delay

The wait in days to receive the reward,

indiff

The requisite proportion of reward needed for the subject to be indifferent to waiting for the full reward or receiving a reduced reward immediately

Brown, et al. (2023). "Episodic future thinking in type 2 diabetes: Further development and validation of the Health Information Thinking control for clinical trials". PLoS ONE 18(8): e0289478 https://journals.plos.org/plosone/article?id=10.1371/journal.pone.0289478