Check preconditions for an input data frame for the prepare_data_frame and jb_rule_check functions.
Source:R/check_input_preconditions.R
check_input_preconditions.RdThis function is a helper function for the prepare_data_frame and jb_rule_check methods.