Estimate the hyperparameters for each group, as well as the variance components of the model, using maximum likelihood estimation.
Source:R/estimate_hyperbolic_model_params.R
estimate_hyperbolic_model_params.RdThis function is a helper function for dd_hyperbolic_model. We recommend not using this function on its own.
Value
A list of two objects: ln_k_mean is a data frame with estimates of the hyperparameters of each group along with the standard error of the estimate. The hyperparameter for each group can be interpreted as the mean ln(k) for a subject in that group. var is a vector with entries sigma_sq and g. sigma_sq is the variance of the observed transformed indifference conditioned on the true ln(k) for the subject. g is related to the variance of the subject random effect, which is equal to g*sigma_sq/T, where T is the number of time points.
Examples
prep_remedi <- prepare_data_frame(remedi)
param_ests <- estimate_hyperbolic_model_params(prep_remedi)